package wusthelper.web.api.v2.dto.response;

import cn.wustlinghang.mywust.data.global.Score;
import lombok.Data;
import wusthelper.web.util.StringUtil;

@Data
public class ScoreResponse {
    /**
     * 课程编号
     */
    private String courseNum;
    /**
     * 课程名称
     */
    private String courseName;
    /**
     * 成绩
     */
    private String grade;
    /**
     * 学分
     */
    private Float courseCredit;
    /**
     * 总学时
     */
    private Float courseHours;
    /**
     * 绩点
     */
    private Float gradePoint;
    /**
     * 考核方式
     */
    private String evaluationMode;
    /**
     * 考试性质
     */
    private String examNature;
    /**
     * 课程性质
     */
    private String courseNature;
    /**
     * 开课学期
     */
    private String schoolTerm;
    /**
     * 重修标记 0--未重修 1--重修
     */
    private Integer rebuildTag;
    /**
     * 补考标记 0--正常考试 1--补考
     */
    private Integer reExamTag;
    /**
     * 缺考/缓考标记 0--正常 1--缺考 2--缓考
     */
    private Integer missExamTag;

    public static ScoreResponse from(Score score) {
        ScoreResponse scoreResponse = new ScoreResponse();
        scoreResponse.setCourseNum(score.getCourseName());
        scoreResponse.setCourseName(score.getCourseName());
        scoreResponse.setGrade(score.getScore());
        //学分
        if ("".equals(score.getCredit())) {
            scoreResponse.setCourseCredit(0.0F);
        } else {
            scoreResponse.setCourseCredit(Float.parseFloat(score.getCredit()));
        }

        //总学时
        if ("".equals(score.getCourseHours())) {
            scoreResponse.setCourseHours(0.0F);
        } else {
            scoreResponse.setCourseHours(Float.parseFloat(score.getCourseHours()));
        }

        //绩点
        if (StringUtil.isPositiveNumber(score.getGradePoint())) {
            scoreResponse.setGradePoint(Float.parseFloat(score.getGradePoint()));
        } else {
            scoreResponse.setGradePoint(convertGradePoint(score.getScore()));
        }

        scoreResponse.setEvaluationMode(score.getEvaluateMethod());
        scoreResponse.setExamNature(score.getKind());
        scoreResponse.setCourseNature(score.getCourseKind());
        scoreResponse.setSchoolTerm(score.getTerm());
//        scoreResponse.setRebuildTag();
//        scoreResponse.setReExamTag();
//        scoreResponse.setMissExamTag();
        //补考判断 0--正常考试 1--补考

        scoreResponse.setReExamTag(0);
        if (score.getFlag().contains("补考") || score.getKind().contains("补考")) {
            scoreResponse.setReExamTag(1);
        }
        //缓考/缺考判断  0--正常 1--缺考 2--缓考
        scoreResponse.setMissExamTag(0);
        if (score.getFlag().contains("缺考") || score.getKind().contains("缺考")) {
            scoreResponse.setMissExamTag(1);
        }
        if (score.getFlag().contains("缓考") || score.getKind().contains("缓考")) {
            scoreResponse.setMissExamTag(2);
        }

        scoreResponse.setRebuildTag(0);

        return scoreResponse;
    }

    /**
     * 转换成绩为学分，支持数字成绩和等级成绩
     *
     * @param gradeStr 成绩字符串
     * @return 换算后的学分
     */
    private static float convertGradePoint(String gradeStr) {
        if (StringUtil.isPositiveNumber(gradeStr)) {
            return StringUtil.numberGradeToGradePoint(gradeStr);
        } else {
            return StringUtil.levelGradeToGradePoint(gradeStr);
        }
    }
}
