package wusthelper.web.api.v2.module.undergrade;

import org.springframework.web.bind.annotation.*;
import wusthelper.web.api.v2.TokenTool;
import wusthelper.web.api.v2.dto.response.CombineLoginResponse;
import wusthelper.web.api.v2.dto.response.CourseResponse;
import wusthelper.web.api.v2.dto.response.StudentInfoResponse;
import wusthelper.web.response.Response;
import wusthelper.web.service.campus.GeneralUserLoginService;
import wusthelper.web.service.campus.undergrad.UndergradCourseTableService;
import wusthelper.web.service.campus.undergrad.UndergradStudentInfoService;

import java.util.ArrayList;

@RestController
@RequestMapping("/v2/jwc")
public class UndergradLoginController {
    private final GeneralUserLoginService generalUserLoginService;

    private final UndergradStudentInfoService studentInfoService;
    private final UndergradCourseTableService courseTableService;

    public UndergradLoginController(GeneralUserLoginService generalUserLoginService,
                                    UndergradStudentInfoService studentInfoService,
                                    UndergradCourseTableService courseTableService) {

        this.generalUserLoginService = generalUserLoginService;
        this.studentInfoService = studentInfoService;
        this.courseTableService = courseTableService;
    }

    @PostMapping("/login")
    public Response<String> login(@RequestParam(value = "stuNum") String username,
                                  @RequestParam(value = "jwcPwd") String password,
                                  @RequestHeader(name = "Platform", required = false) String platform) {

        var user = generalUserLoginService.login(username, password, GeneralUserLoginService.UserType.Undergrad);

        String token = TokenTool.signToken(user.getUid(), user.getStuNum());

        return Response.success(token);
    }

    /**
     * v2接口的组合登录，其实没必要，所谓的请求减负在这里没啥太大用处，这点压力算不上什么，
     * 不仅没必要，还增大了登陆耗时，容易超时，
     * v3版本时将会移除
     *
     * @param username 用户名
     * @param password 密码
     * @param term     学期
     * @param platform 平台
     * @return .
     */
    @PostMapping("/combine-login")
    public Response<CombineLoginResponse> combineLogin(@RequestParam(value = "stuNum") String username,
                                                       @RequestParam(value = "jwcPwd") String password,
                                                       @RequestParam(value = "term") String term,
                                                       @RequestHeader(name = "Platform", required = false) String platform) {

        var user = generalUserLoginService.login(username, password, GeneralUserLoginService.UserType.Undergrad);
        var studentInfo = studentInfoService.getStudentInfo(username);
        var courses = courseTableService.getCourseTable(username, term);

        var studentResponse = StudentInfoResponse.from(studentInfo);
        var courseResponses = new ArrayList<CourseResponse>(courses.size());
        for (var course : courses) {
            courseResponses.add(CourseResponse.from(course));
        }

        String token = TokenTool.signToken(user.getUid(), user.getStuNum());

        var response = new CombineLoginResponse(token, courseResponses, studentResponse);
        return Response.success(response);
    }
}