package wusthelper.internal.graduate.services;

import cn.wustlinghang.mywust.core.parser.graduate.GraduateCourseTableParser;
import cn.wustlinghang.mywust.core.request.service.graduate.GraduateCourseTableApiService;
import cn.wustlinghang.mywust.data.global.Course;
import cn.wustlinghang.mywust.exception.ApiException;
import cn.wustlinghang.mywust.network.RequestClientOption;
import jakarta.enterprise.context.ApplicationScoped;
import wusthelper.code.ServiceCode;
import wusthelper.internal.rpc.exception.RpcException;

import java.io.IOException;
import java.util.List;

@ApplicationScoped
public class CourseTableService extends BaseService {

    private final RequestClientOption requestClientOption;

    private final GraduateCourseTableApiService courseTableApiService;
    private final GraduateCourseTableParser courseTableParser;

    public CourseTableService(RequestClientOption requestClientOption,
                              GraduateCourseTableApiService courseTableApiService,
                              GraduateCourseTableParser courseTableParser) {
        this.requestClientOption = requestClientOption;

        this.courseTableApiService = courseTableApiService;
        this.courseTableParser = courseTableParser;
    }

    public String getCourseTable(String cookie) throws RpcException {
        try {
            return courseTableApiService.getPage(cookie, requestClientOption);
        } catch (ApiException e) {
            throw wrapApiException(e);
        } catch (IOException e) {
            throw new RpcException(ServiceCode.NetworkError);
        }
    }

    public List<Course> parseCourseTable(String data) throws RpcException {
        try {
            return courseTableParser.parse(data);
        } catch (Exception e) {
            throw new RpcException(ServiceCode.ParseError);
        }
    }
}
