package wusthelper.internal.graduate.services;

import cn.wustlinghang.mywust.core.parser.graduate.GraduateScoreParser;
import cn.wustlinghang.mywust.core.request.service.graduate.GraduateScoreApiService;
import cn.wustlinghang.mywust.data.global.Score;
import cn.wustlinghang.mywust.exception.ApiException;
import cn.wustlinghang.mywust.network.RequestClientOption;
import jakarta.enterprise.context.ApplicationScoped;
import wusthelper.code.ServiceCode;
import wusthelper.internal.rpc.exception.RpcException;

import java.io.IOException;
import java.util.List;

@ApplicationScoped
public class ScoreService extends BaseService {

    private final RequestClientOption requestClientOption;

    private final GraduateScoreApiService scoreApiService;
    private final GraduateScoreParser scoreParser;

    public ScoreService(RequestClientOption requestClientOption,
                        GraduateScoreApiService scoreApiService,
                        GraduateScoreParser scoreParser) {
        this.requestClientOption = requestClientOption;

        this.scoreApiService = scoreApiService;
        this.scoreParser = scoreParser;
    }

    public String getScore(String cookie) throws RpcException {
        try {
            return scoreApiService.getPage(cookie, requestClientOption);
        } catch (ApiException e) {
            throw wrapApiException(e);
        } catch (IOException e) {
            throw new RpcException(ServiceCode.NetworkError);
        }
    }

    public List<Score> parseScore(String data) throws RpcException {
        try {
            return scoreParser.parse(data);
        } catch (Exception e) {
            throw new RpcException(ServiceCode.ParseError);
        }
    }
}
