package wusthelper.internal.graduate.services;

import cn.wustlinghang.mywust.core.parser.graduate.GraduateStudentInfoPageParser;
import cn.wustlinghang.mywust.core.request.service.graduate.GraduateStudentInfoApiService;
import cn.wustlinghang.mywust.data.global.StudentInfo;
import cn.wustlinghang.mywust.exception.ApiException;
import cn.wustlinghang.mywust.network.RequestClientOption;
import jakarta.enterprise.context.ApplicationScoped;
import wusthelper.code.ServiceCode;
import wusthelper.internal.rpc.exception.RpcException;

import java.io.IOException;

@ApplicationScoped
public class StudentInfoService extends BaseService {

    private final RequestClientOption requestClientOption;

    private final GraduateStudentInfoApiService studentInfoApiService;
    private final GraduateStudentInfoPageParser studentInfoPageParser;

    public StudentInfoService(RequestClientOption requestClientOption,
                              GraduateStudentInfoApiService studentInfoApiService,
                              GraduateStudentInfoPageParser studentInfoPageParser) {
        this.requestClientOption = requestClientOption;

        this.studentInfoApiService = studentInfoApiService;
        this.studentInfoPageParser = studentInfoPageParser;
    }

    public String getStudentInfoPage(String cookie) throws RpcException {
        try {
            return studentInfoApiService.getPage(cookie, requestClientOption);
        } catch (ApiException e) {
            throw wrapApiException(e);
        } catch (IOException e) {
            throw new RpcException(ServiceCode.NetworkError);
        }
    }

    public StudentInfo parseStudentInfo(String data) throws RpcException {
        try {
            return studentInfoPageParser.parse(data);
        } catch (Exception e) {
            throw new RpcException(ServiceCode.ParseError);
        }
    }
}
