package wusthelper.internal.library.api.http.v1.handler;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Response;
import wusthelper.code.ServiceCode;
import wusthelper.internal.rpc.response.RpcResponseDto;

public abstract class BaseExceptionHandler {
    public static final String EXCEPTION_HEADER_KEY = "X-exception-handler";

    private static final ObjectMapper objectMapper = new ObjectMapper();

    public Response toResponse(int code, String handlerName) {
        return toResponse(Response.Status.OK, code, handlerName);
    }

    public Response toResponse(int status, int code, String handlerName) {
        return toResponse(Response.Status.fromStatusCode(status), code, handlerName);
    }

    public Response toResponse(Response.Status status, int code, String handlerName) {
        Object response;
        try {
            response = objectMapper.writeValueAsString(RpcResponseDto.error(code));
        } catch (JsonProcessingException e) {
            response = RpcResponseDto.error(ServiceCode.ServerInternalError);
        }

        return Response.status(status)
                .entity(response)
                .header(EXCEPTION_HEADER_KEY, handlerName)
                .type(MediaType.APPLICATION_JSON)
                .build();
    }
}
