package wusthelper.internal.library.services;

import cn.wustlinghang.mywust.core.request.service.library.LoanHistoryApiService;
import cn.wustlinghang.mywust.data.library.PagingResult;
import cn.wustlinghang.mywust.data.library.origin.HistoryLoanBook;
import cn.wustlinghang.mywust.exception.ApiException;
import cn.wustlinghang.mywust.exception.ParseException;
import jakarta.enterprise.context.ApplicationScoped;
import lombok.extern.slf4j.Slf4j;
import wusthelper.code.ServiceCode;
import wusthelper.internal.rpc.exception.RpcException;

import java.io.IOException;
import java.util.List;

@Slf4j
@ApplicationScoped
public class LoanHistoryService extends BaseService {
    private final LoanHistoryApiService api;

    public LoanHistoryService(LoanHistoryApiService api) {
        this.api = api;
    }

    public PagingResult<List<HistoryLoanBook>> getLoanHistory(String cookie, int page, int pageSize)
            throws RpcException {
        try {
            return api.getLoanHistory(cookie, page, pageSize);
        } catch (ApiException e) {
            throw wrapApiException(e);
        } catch (IOException e) {
            throw new RpcException(ServiceCode.NetworkError);
        } catch (ParseException e) {
            log.error("解析错误：", e);
            throw new RpcException(ServiceCode.ParseError);
        }
    }
}
