package wusthelper.internal.library.services;

import cn.wustlinghang.mywust.core.request.service.auth.LibraryLogin;
import cn.wustlinghang.mywust.exception.ApiException;
import cn.wustlinghang.mywust.network.RequestClientOption;
import jakarta.enterprise.context.ApplicationScoped;
import lombok.extern.slf4j.Slf4j;
import wusthelper.code.ServiceCode;
import wusthelper.internal.rpc.exception.RpcException;

import java.io.IOException;

@Slf4j
@ApplicationScoped
public class LoginService {
    private final RequestClientOption option;
    private final LibraryLogin libraryLogin;

    public LoginService(RequestClientOption option,
                        LibraryLogin libraryLogin) {
        this.option = option;
        this.libraryLogin = libraryLogin;
    }

    public String login(String username, String password) throws RpcException {
        try {
            return libraryLogin.getLoginCookie(username, password, option);
        } catch (ApiException e) {
            throw wrapApiException(e);
        } catch (IOException e) {
            throw new RpcException(ServiceCode.NetworkError);
        }
    }

    public boolean verify(String cookie) throws RpcException {
        try {
            return libraryLogin.checkCookie(cookie, option);
        } catch (IOException e) {
            throw new RpcException(ServiceCode.NetworkError);
        }
    }

    private RpcException wrapApiException(ApiException e) {
        int errorCode = switch (e.getCode()) {
            case NETWORK_EXCEPTION -> ServiceCode.NetworkError;
            case UNI_LOGIN_PASSWORD_WRONG -> ServiceCode.UndergradPasswordWrong;
            case UNI_LOGIN_USER_NOT_EXISTS -> ServiceCode.UndergradUserNotExists;
            case UNI_LOGIN_USER_BANNED -> ServiceCode.UndergradUserBanned;
            case UNI_LOGIN_USER_DISABLED -> ServiceCode.UndergradUserDisabled;
            case UNI_LOGIN_NEED_CHANGE_PASSWORD -> ServiceCode.UndergradPasswordNeedModify;
            case UNDERGRAD_BANNED_IN_EXCLUSIVE_TIME -> ServiceCode.UndergradBannedInExclusiveTime;
            case UNI_LOGIN_USER_NOT_ONLY, UNI_LOGIN_NO_REGISTER, UNI_LOGIN_NEED_TFA -> ServiceCode.Unknown;
            default -> {
                log.error("图书馆：登录代理请求异常，异常未处理");
                log.error("异常：", e);
                yield ServiceCode.Unknown;
            }
        };

        return new RpcException(errorCode);
    }
}
