package wusthelper.internal.physics.services;

import cn.wustlinghang.mywust.core.request.service.auth.PhysicsLogin;
import cn.wustlinghang.mywust.exception.ApiException;
import cn.wustlinghang.mywust.exception.ParseException;
import cn.wustlinghang.mywust.network.RequestClientOption;
import jakarta.enterprise.context.ApplicationScoped;
import lombok.extern.slf4j.Slf4j;
import wusthelper.code.ServiceCode;
import wusthelper.internal.rpc.exception.RpcException;

import java.io.IOException;

@Slf4j
@ApplicationScoped
public class LoginService {
    private final RequestClientOption option;

    private final PhysicsLogin physicsLogin;

    public LoginService(RequestClientOption option,
                        PhysicsLogin physicsLogin) {
        this.option = option;
        this.physicsLogin = physicsLogin;
    }

    public String login(String username, String password) throws RpcException {
        try {
            return physicsLogin.getLoginCookie(username, password, option);
        } catch (ApiException e) {
            throw wrapApiException(e);
        } catch (IOException e) {
            throw new RpcException(ServiceCode.NetworkError);
        } catch (ParseException e) {
            log.error("物理实验：登录时出现页面参数解析问题", e);
            throw new RpcException(ServiceCode.ParseError);
        }
    }

    public boolean verify(String cookie) throws RpcException {
        try {
            return physicsLogin.checkCookie(cookie, option);
        } catch (IOException e) {
            throw new RpcException(ServiceCode.NetworkError);
        }
    }

    private RpcException wrapApiException(ApiException e) {
        int errorCode = switch (e.getCode()) {
            case NETWORK_EXCEPTION -> ServiceCode.NetworkError;
            case PHYSICS_PASSWORD_WRONG -> ServiceCode.PhysicsPasswordWrong;
            case PHYSICS_NOT_CURRENT_TERM -> ServiceCode.PhysicsUserNotCurrentTerm;
            default -> {
                log.error("物理实验：登录代理请求异常，异常未处理");
                log.error("异常：", e);
                yield ServiceCode.Unknown;
            }
        };

        return new RpcException(errorCode);
    }
}
