package wusthelper.internal.undergrad.services;

import cn.wustlinghang.mywust.core.parser.undergraduate.UndergradCourseTableParser;
import cn.wustlinghang.mywust.core.request.service.undergraduate.UndergradCourseTableApiService;
import cn.wustlinghang.mywust.data.global.Course;
import cn.wustlinghang.mywust.exception.ApiException;
import jakarta.enterprise.context.ApplicationScoped;
import lombok.extern.slf4j.Slf4j;
import wusthelper.code.ServiceCode;
import wusthelper.internal.rpc.exception.RpcException;

import java.io.IOException;
import java.util.List;

@Slf4j
@ApplicationScoped
public class CourseTableService extends BaseService {
    private final UndergradCourseTableParser courseTableParser;
    private final UndergradCourseTableApiService courseTableApiService;

    public CourseTableService(UndergradCourseTableParser courseTableParser,
                              UndergradCourseTableApiService courseTableApiService) {
        this.courseTableParser = courseTableParser;
        this.courseTableApiService = courseTableApiService;
    }

    public String getCourseTable(String cookie, String term) throws RpcException {
        try {
            return courseTableApiService.getPage(term, cookie);
        } catch (ApiException e) {
            throw wrapApiException(e);
        } catch (IOException e) {
            throw new RpcException(ServiceCode.NetworkError);
        }
    }

    public List<Course> parseCourseTable(String data) throws RpcException {
        try {
            if (data.contains("评教")) {
                throw new RpcException(ServiceCode.UndergradNeedEvaluate);
            }

            return courseTableParser.parse(data);
        } catch (Exception e) {
            log.error("解析错误：", e);
            throw new RpcException(ServiceCode.ParseError);
        }
    }
}
