package wusthelper.internal.undergrad.services;

import cn.wustlinghang.mywust.core.parser.undergraduate.UndergradCreditStatusParser;
import cn.wustlinghang.mywust.core.request.service.undergraduate.UndergradCreditStatusApiService;
import cn.wustlinghang.mywust.exception.ApiException;
import cn.wustlinghang.mywust.network.RequestClientOption;
import jakarta.enterprise.context.ApplicationScoped;
import lombok.extern.slf4j.Slf4j;
import wusthelper.code.ServiceCode;
import wusthelper.internal.rpc.exception.RpcException;

import java.io.IOException;

@Slf4j
@ApplicationScoped
public class CreditStatusService extends BaseService {
    private final UndergradCreditStatusApiService creditStatusApiService;
    private final UndergradCreditStatusParser creditStatusParser;

    private final RequestClientOption requestClientOption;

    public CreditStatusService(UndergradCreditStatusApiService creditStatusApiService,
                               UndergradCreditStatusParser creditStatusParser,
                               RequestClientOption requestClientOption) {
        this.creditStatusApiService = creditStatusApiService;
        this.creditStatusParser = creditStatusParser;

        this.requestClientOption = requestClientOption;
    }

    public String getCreditStatus(String cookie) throws RpcException {
        try {
            return creditStatusApiService.getPage(cookie, requestClientOption, false);
        } catch (ApiException e) {
            throw wrapApiException(e);
        } catch (IOException e) {
            throw new RpcException(ServiceCode.NetworkError);
        }
    }

    public String parseCreditStatus(String data) throws RpcException {
        try {
            return creditStatusParser.parse(data);
        } catch (Exception e) {
            log.error("解析错误：", e);
            throw new RpcException(ServiceCode.ParseError);
        }
    }
}
