package wusthelper.internal.undergrad.services;

import cn.wustlinghang.mywust.core.parser.undergraduate.UndergradExamDelayParser;
import cn.wustlinghang.mywust.core.request.service.undergraduate.UndergradExamDelayApiService;
import cn.wustlinghang.mywust.data.undergrad.ExamDelayApplication;
import cn.wustlinghang.mywust.exception.ApiException;
import lombok.extern.slf4j.Slf4j;
import wusthelper.code.ServiceCode;
import wusthelper.internal.rpc.exception.RpcException;
import jakarta.enterprise.context.ApplicationScoped;

import java.io.IOException;
import java.util.List;

@Slf4j
@ApplicationScoped
public class ExamDelayApplicationService extends BaseService {
    private final UndergradExamDelayApiService examDelayApiService;
    private final UndergradExamDelayParser examDelayParser;

    public ExamDelayApplicationService(UndergradExamDelayApiService examDelayApiService,
                                       UndergradExamDelayParser examDelayParser) {
        this.examDelayApiService = examDelayApiService;
        this.examDelayParser = examDelayParser;
    }

    public String getExamDelayApplications(String cookie, String term, String activityId)
            throws RpcException {
        try {
            return examDelayApiService.getPage(term, activityId, cookie);
        } catch (ApiException e) {
            throw wrapApiException(e);
        } catch (IOException e) {
            throw new RpcException(ServiceCode.NetworkError);
        }
    }

    public List<ExamDelayApplication> parseExamDelayApplications(String data) throws RpcException {
        try {
            return examDelayParser.parse(data);
        } catch (Exception e) {
            log.error("解析错误：", e);
            throw new RpcException(ServiceCode.ParseError);
        }
    }
}
