package wusthelper.internal.undergrad.services;

import cn.wustlinghang.mywust.core.parser.undergraduate.UndergradStudentInfoPageParser;
import cn.wustlinghang.mywust.core.request.service.undergraduate.UndergradStudentInfoApiService;
import cn.wustlinghang.mywust.data.global.StudentInfo;
import cn.wustlinghang.mywust.exception.ApiException;
import lombok.extern.slf4j.Slf4j;
import wusthelper.code.ServiceCode;
import wusthelper.internal.rpc.exception.RpcException;
import jakarta.enterprise.context.ApplicationScoped;

import java.io.IOException;

@Slf4j
@ApplicationScoped
public class StudentInfoService extends BaseService {
    private final UndergradStudentInfoApiService studentInfoApiService;
    private final UndergradStudentInfoPageParser studentInfoPageParser;

    public StudentInfoService(UndergradStudentInfoApiService studentInfoApiService,
                              UndergradStudentInfoPageParser studentInfoPageParser) {
        this.studentInfoApiService = studentInfoApiService;
        this.studentInfoPageParser = studentInfoPageParser;
    }

    public String getStudentInfoPage(String cookie) throws RpcException {
        try {
            return studentInfoApiService.getPage(cookie);
        } catch (ApiException e) {
            throw wrapApiException(e);
        } catch (IOException e) {
            throw new RpcException(ServiceCode.NetworkError);
        }
    }

    public StudentInfo parseStudentInfo(String data) throws RpcException {
        try {
            return studentInfoPageParser.parse(data);
        } catch (Exception e) {
            log.error("解析错误：", e);
            throw new RpcException(ServiceCode.ParseError);
        }
    }
}
