package wusthelper.internal.undergrad.services;

import cn.wustlinghang.mywust.core.parser.undergraduate.UndergradTrainingPlanPageParser;
import cn.wustlinghang.mywust.core.request.service.undergraduate.UndergradTrainingPlanApiService;
import cn.wustlinghang.mywust.exception.ApiException;
import jakarta.enterprise.context.ApplicationScoped;
import lombok.extern.slf4j.Slf4j;
import wusthelper.code.ServiceCode;
import wusthelper.internal.rpc.exception.RpcException;

import java.io.IOException;

@Slf4j
@ApplicationScoped
public class TrainingPlanService extends BaseService {
    private final UndergradTrainingPlanApiService trainingPlanApiService;
    private final UndergradTrainingPlanPageParser trainingPlanPageParser;

    public TrainingPlanService(UndergradTrainingPlanApiService trainingPlanApiService,
                               UndergradTrainingPlanPageParser trainingPlanPageParser) {
        this.trainingPlanApiService = trainingPlanApiService;
        this.trainingPlanPageParser = trainingPlanPageParser;
    }

    public String getTrainingPlan(String cookie) throws RpcException {
        try {
            return trainingPlanApiService.getPage(cookie);
        } catch (ApiException e) {
            throw wrapApiException(e);
        } catch (IOException e) {
            throw new RpcException(ServiceCode.NetworkError);
        }
    }

    public String parseTrainingPlan(String data) throws RpcException {
        try {
            return trainingPlanPageParser.parse(data);
        } catch (Exception e) {
            log.error("解析错误：", e);
            throw new RpcException(ServiceCode.ParseError);
        }
    }
}
